Home
last modified time | relevance | path

Searched refs:out (Results 1 – 25 of 4549) sorted by relevance

12345678910>>...182

/llvm-project/clang-tools-extra/test/clang-tidy/checkers/bugprone/
H A Dbranch-clone.cpp3 void test_basic1(int in, int &out) { in test_basic1() argument
6 out++; in test_basic1()
9 out++; in test_basic1()
11 out++; in test_basic1()
14 void test_basic2(int in, int &out) { in test_basic2() argument
17 out++; in test_basic2()
21 out++; in test_basic2()
24 out++; in test_basic2()
27 void test_basic3(int in, int &out) { in test_basic3() argument
30 out++; in test_basic3()
[all …]
/llvm-project/clang/test/SemaCUDA/
H A Ddevice-use-host-var.cu66 __device__ void dev_fun(int *out) { in dev_fun() argument
71 *out = ref_dev_var; in dev_fun()
72 *out = ref_constant_var; in dev_fun()
73 *out = ref_shared_var; in dev_fun()
74 *out = global_dev_var; in dev_fun()
75 *out = global_constant_var; in dev_fun()
76 *out = global_shared_var; in dev_fun()
79 *out = global_host_var; // dev-error {{reference to __host__ variable 'global_host_var' in __device__ function}} in dev_fun()
80 *out = global_const_var; in dev_fun()
81 *out in dev_fun()
129 global_fun(int * out) global_fun() argument
152 host_dev_fun(int * out) host_dev_fun() argument
175 inline_host_dev_fun(int * out) inline_host_dev_fun() argument
198 dev_lambda_capture_by_ref(int * out) dev_lambda_capture_by_ref() argument
224 dev_lambda_capture_by_copy(int * out) dev_lambda_capture_by_copy() argument
[all...]
/llvm-project/libc/AOR_v20.02/math/test/rtest/
H A Dsemi.c12 static void test_rint(uint32 *in, uint32 *out, in test_rint() argument
23 out[0] = in[0]; in test_rint()
24 out[1] = in[1]; in test_rint()
33 out[0] = sign | (roundup ? 0x3FF00000 : 0); in test_rint()
34 out[1] = 0; in test_rint()
61 out[0] = xh; in test_rint()
62 out[1] = xl; in test_rint()
65 char *test_ceil(uint32 *in, uint32 *out) { in test_ceil() argument
66 test_rint(in, out, 0, 1); in test_ceil()
70 char *test_floor(uint32 *in, uint32 *out) { in test_floor() argument
[all …]
H A Dsemi.h14 char *test_ceil(uint32 *in, uint32 *out);
15 char *test_floor(uint32 *in, uint32 *out);
16 char *test_fmod(uint32 *a, uint32 *b, uint32 *out);
17 char *test_ldexp(uint32 *x, uint32 *n, uint32 *out);
18 char *test_frexp(uint32 *x, uint32 *out, uint32 *nout);
20 char *test_ceilf(uint32 *in, uint32 *out);
21 char *test_floorf(uint32 *in, uint32 *out);
22 char *test_fmodf(uint32 *a, uint32 *b, uint32 *out);
23 char *test_ldexpf(uint32 *x, uint32 *n, uint32 *out);
24 char *test_frexpf(uint32 *x, uint32 *out, uint32 *nout);
[all …]
/llvm-project/clang/test/CodeGenOpenCL/
H A Dbuiltins-amdgcn-vi.cl15 void test_div_fixup_f16(global half* out, half a, half b, half c)
17 *out = __builtin_amdgcn_div_fixuph(a, b, c);
22 void test_rcp_f16(global half* out, half a)
24 *out = __builtin_amdgcn_rcph(a);
29 void test_sqrt_f16(global half* out, half a)
31 *out = __builtin_amdgcn_sqrth(a);
36 void test_rsq_f16(global half* out, half a)
38 *out = __builtin_amdgcn_rsqh(a);
43 void test_sin_f16(global half* out, half a)
45 *out
[all...]
/llvm-project/flang/test/Lower/Intrinsics/
H A Dieee_logb.f9074 call out(ieee_value(x, ieee_signaling_nan)) argument
75 call out(ieee_value(x, ieee_quiet_nan))
76 call out(ieee_value(x, ieee_negative_inf))
77 call out( -huge(x))
78 call out( -huge(x)/2)
79 call out(-sqrt(huge(x)))
80 call out(-2000.0_k)
81 call out( -9.9_k)
82 call out( -9.0_k)
83 call out( -8.0_k)
[all …]
/llvm-project/llvm/test/CodeGen/X86/
H A Delementwise-store-of-scalar-splat.ll13 define void @vec16_i8(ptr %in.elt.ptr, ptr %out.vec.ptr) nounwind {
23 %out.elt0.ptr = getelementptr i8, ptr %out.vec.ptr, i64 0
24 store i8 %in.elt, ptr %out.elt0.ptr, align 64
25 %out.elt1.ptr = getelementptr i8, ptr %out.vec.ptr, i64 1
26 store i8 %in.elt, ptr %out.elt1.ptr, align 1
30 define void @vec32_i8(ptr %in.elt.ptr, ptr %out.vec.ptr) nounwind {
42 %out.elt0.ptr = getelementptr i8, ptr %out.vec.ptr, i64 0
43 store i8 %in.elt, ptr %out.elt0.ptr, align 64
44 %out.elt1.ptr = getelementptr i8, ptr %out.vec.ptr, i64 1
45 store i8 %in.elt, ptr %out.elt1.ptr, align 1
[all …]
/llvm-project/libcxx/test/std/utilities/memory/specialized.algorithms/uninitialized.move/
H A Dranges_uninitialized_move.pass.cpp50 Buffer<Counted, 1> out; in main() local
54 auto result = std::ranges::uninitialized_move(in, in, out.begin(), out.end()); in main()
59 assert(result.out == out.begin()); in main()
64 auto result = std::ranges::uninitialized_move(view, out); in main()
69 assert(result.out == out.begin()); in main()
76 auto result = std::ranges::uninitialized_move(range.begin(), range.end(), out.begin(), out in main()
102 Buffer<Counted, N> out; main() local
124 Buffer<Counted, N> out; main() local
148 Buffer<Counted, 5> out; main() local
171 Buffer<Counted, 5> out; main() local
194 Buffer<Counted, 5> out; main() local
220 int out[N] = {6, 7, 8, 9, 10}; main() local
237 Buffer<Counted, 5> out; main() local
263 Buffer<Counted, 5> out; main() local
289 Buffer<Counted, N> out; main() local
305 Buffer<Counted, N> out; main() local
322 Buffer<double, N> out; main() local
332 Buffer<double, N> out; main() local
343 Buffer<Counted, M> out; main() local
362 Buffer<Counted, M> out; main() local
381 Buffer<int, N> out; main() local
412 Buffer<int, N> out; main() local
418 Buffer<int, N> out; main() local
427 Buffer<MoveOnly, 4> out; main() local
433 Buffer<MoveOnly, 4> out; main() local
[all...]
H A Dranges_uninitialized_move_n.pass.cpp47 Buffer<Counted, 1> out; in main() local
50 auto result = std::ranges::uninitialized_move_n(in, 0, out.begin(), out.end()); in main()
55 assert(result.out == out.begin()); in main()
63 Buffer<Counted, N> out; in main() local
66 auto result = std::ranges::uninitialized_move_n(in, N, out.begin(), out.end()); in main()
74 assert(std::equal(in, in + N, out.begin(), out in main()
88 Buffer<Counted, 5> out; main() local
112 Buffer<Counted, N> out; main() local
128 Buffer<double, N> out; main() local
139 Buffer<Counted, M> out; main() local
157 Buffer<int, N> out; main() local
181 Buffer<int, N> out; main() local
189 Buffer<MoveOnly, 4> out; main() local
[all...]
/llvm-project/libcxx/test/std/utilities/memory/specialized.algorithms/uninitialized.copy/
H A Dranges_uninitialized_copy.pass.cpp49 Buffer<Counted, 1> out; in main() local
53 auto result = std::ranges::uninitialized_copy(in, in, out.begin(), out.end()); in main()
58 assert(result.out == out.begin()); in main()
63 auto result = std::ranges::uninitialized_copy(view, out); in main()
68 assert(result.out == out.begin()); in main()
75 auto result = std::ranges::uninitialized_copy(range.begin(), range.end(), out.begin(), out in main()
101 Buffer<Counted, N> out; main() local
124 Buffer<Counted, N> out; main() local
148 Buffer<Counted, 5> out; main() local
171 Buffer<Counted, 5> out; main() local
194 Buffer<Counted, 5> out; main() local
220 int out[N] = {6, 7, 8, 9, 10}; main() local
238 Counted out[N] = {Counted(6), Counted(7), Counted(8), Counted(9), Counted(10)}; main() local
262 Counted out[N] = {Counted(6), Counted(7), Counted(8), Counted(9), Counted(10)}; main() local
285 Buffer<Counted, N> out; main() local
301 Buffer<Counted, N> out; main() local
318 Buffer<double, N> out; main() local
328 Buffer<double, N> out; main() local
339 Buffer<Counted, M> out; main() local
358 Buffer<Counted, M> out; main() local
389 Buffer<int, N> out; main() local
395 Buffer<int, N> out; main() local
[all...]
/llvm-project/libcxx/test/std/algorithms/alg.modifying.operations/alg.copy/
H A Dranges.copy.pass.cpp32 concept HasCopyIt = requires(In in, Sent sent, Out out) { std::ranges::copy(in, sent, out); };
45 concept HasCopyR = requires(Range range, Out out) { std::ranges::copy(range, out); };
64 std::array<int, 4> out; in test_iterators() local
66 std::ranges::copy(In(in.data()), Sent(In(in.data() + in.size())), Out(out.data())); in test_iterators()
67 assert(in == out); in test_iterators()
69 assert(base(ret.out) == out.data() + out.size()); in test_iterators()
73 std::array<int, 4> out; in test_iterators() local
75 …std::same_as<std::ranges::in_out_result<In, Out>> auto ret = std::ranges::copy(range, Out(out.data… in test_iterators()
76 assert(in == out); in test_iterators()
78 assert(base(ret.out) == out.data() + out.size()); in test_iterators()
[all …]
H A Dranges.copy_backward.pass.cpp34 …t HasCopyBackwardIt = requires(In in, Sent sent, Out out) { std::ranges::copy_backward(in, sent, o…
47 concept HasCopyBackwardR = requires(Range range, Out out) { std::ranges::copy_backward(range, out);…
65 std::array<int, 4> out; in test_iterators() local
67 …anges::copy_backward(In(in.data()), Sent(In(in.data() + in.size())), Out(out.data() + out.size())); in test_iterators()
68 assert(in == out); in test_iterators()
70 assert(base(ret.out) == out.data()); in test_iterators()
74 std::array<int, 4> out; in test_iterators() local
77 std::ranges::copy_backward(range, Out(out.data() + out.size())); in test_iterators()
78 assert(in == out); in test_iterators()
80 assert(base(ret.out) == out.data()); in test_iterators()
[all …]
H A Dranges.copy_if.pass.cpp53 concept HasCopyIfR = requires(Range range, Out out) { std::ranges::copy_if(range, out, Func{}); };
71 std::array<int, 4> out; in test_iterators() local
75 Out(out.data()), in test_iterators()
77 assert(in == out); in test_iterators()
79 assert(base(ret.out) == out.data() + out.size()); in test_iterators()
83 std::array<int, 4> out; in test_iterators() local
86 std::ranges::copy_if(range, Out(out.data()), [](int) { return true; }); in test_iterators()
87 assert(in == out); in test_iterators()
89 assert(base(ret.out) == out.data() + out.size()); in test_iterators()
96 std::array<int, 0> out; in test_iterators() local
[all …]
/llvm-project/llvm/test/CodeGen/AMDGPU/
H A Dmerge-stores.ll15 define amdgpu_kernel void @merge_global_store_2_constants_i8(ptr addrspace(1) %out) #0 {
16 %out.gep.1 = getelementptr i8, ptr addrspace(1) %out, i32 1
18 store i8 123, ptr addrspace(1) %out.gep.1
19 store i8 456, ptr addrspace(1) %out, align 2
27 define amdgpu_kernel void @merge_global_store_2_constants_i8_natural_align(ptr addrspace(1) %out) #…
28 %out.gep.1 = getelementptr i8, ptr addrspace(1) %out, i32 1
30 store i8 123, ptr addrspace(1) %out.gep.1
31 store i8 456, ptr addrspace(1) %out
37 define amdgpu_kernel void @merge_global_store_2_constants_i16(ptr addrspace(1) %out) #0 {
38 %out.gep.1 = getelementptr i16, ptr addrspace(1) %out, i32 1
[all …]
/llvm-project/lldb/test/API/types/
H A Dbasic_type.cpp92 FILE *out = stdout; in main() local
99 out = fopen (argv[1], "w"); in main()
136 fprintf (out, "%s: a = '" T_PRINTF_FORMAT "'\n", T_CSTR, a); in main()
137 fprintf (out, "%s*: %p => *a_ptr = '" T_PRINTF_FORMAT "'\n", T_CSTR, a_ptr, *a_ptr); in main()
138 fprintf (out, "%s&: @%p => a_ref = '" T_PRINTF_FORMAT "'\n", T_CSTR, &a_ref, a_ref); in main()
140 … fprintf (out, "%s[2]: a_array_bounded[0] = '" T_PRINTF_FORMAT "'\n", T_CSTR, a_array_bounded[0]); in main()
141 … fprintf (out, "%s[2]: a_array_bounded[1] = '" T_PRINTF_FORMAT "'\n", T_CSTR, a_array_bounded[1]); in main()
143 …fprintf (out, "%s[]: a_array_unbounded[0] = '" T_PRINTF_FORMAT "'\n", T_CSTR, a_array_unbounded[0]… in main()
144 …fprintf (out, "%s[]: a_array_unbounded[1] = '" T_PRINTF_FORMAT "'\n", T_CSTR, a_array_unbounded[1]… in main()
146 …fprintf (out, "(a_class) a_class_instance.m_a = '" T_PRINTF_FORMAT "'\n", a_class_instance.get_a()… in main()
[all …]
/llvm-project/llvm/test/Transforms/LoadStoreVectorizer/AMDGPU/
H A Dmerge-stores-private.ll20 define amdgpu_kernel void @merge_private_store_4_vector_elts_loads_v4i32(ptr addrspace(5) %out) #0 {
21 %out.gep.1 = getelementptr i32, ptr addrspace(5) %out, i32 1
22 %out.gep.2 = getelementptr i32, ptr addrspace(5) %out, i32 2
23 %out.gep.3 = getelementptr i32, ptr addrspace(5) %out, i32 3
25 store i32 9, ptr addrspace(5) %out
26 store i32 1, ptr addrspace(5) %out.gep.1
27 store i32 23, ptr addrspace(5) %out.gep.2
28 store i32 19, ptr addrspace(5) %out.gep.3
33 ; ALIGNED: store i32 9, ptr addrspace(5) %out, align 1
34 ; ALIGNED: store i32 1, ptr addrspace(5) %out.gep.1, align 1
[all …]
H A Dweird-type-accesses.ll21 define amdgpu_kernel void @merge_store_2_constants_i1(ptr addrspace(1) %out) #0 {
22 %out.gep.1 = getelementptr i1, ptr addrspace(1) %out, i32 1
23 store i1 true, ptr addrspace(1) %out.gep.1
24 store i1 false, ptr addrspace(1) %out
31 define amdgpu_kernel void @merge_store_2_constants_i2(ptr addrspace(1) %out) #0 {
32 %out.gep.1 = getelementptr i2, ptr addrspace(1) %out, i32 1
33 store i2 1, ptr addrspace(1) %out.gep.1
34 store i2 -1, ptr addrspace(1) %out
41 define amdgpu_kernel void @merge_different_store_sizes_i1_i8(ptr addrspace(1) %out) #0 {
42 %out.gep.1 = getelementptr i8, ptr addrspace(1) %out, i32 1
[all …]
H A Dmerge-stores.ll11 define amdgpu_kernel void @merge_global_store_2_constants_i8(ptr addrspace(1) %out) #0 {
16 %out.gep.1 = getelementptr i8, ptr addrspace(1) %out, i32 1
18 store i8 123, ptr addrspace(1) %out.gep.1
19 store i8 456, ptr addrspace(1) %out, align 2
23 define amdgpu_kernel void @merge_global_store_2_constants_i8_natural_align(ptr addrspace(1) %out) #…
28 %out.gep.1 = getelementptr i8, ptr addrspace(1) %out, i32 1
30 store i8 123, ptr addrspace(1) %out.gep.1
31 store i8 456, ptr addrspace(1) %out
35 define amdgpu_kernel void @merge_global_store_2_constants_i16(ptr addrspace(1) %out) #0 {
40 %out.gep.1 = getelementptr i16, ptr addrspace(1) %out, i32 1
[all …]
/llvm-project/third-party/benchmark/src/
H A Djson_reporter.cc111 std::ostream& out = GetOutputStream(); in ReportContext() local
113 out << "{\n"; in ReportContext()
117 out << inner_indent << "\"context\": {\n"; in ReportContext()
121 out << indent << FormatKV("date", walltime_value) << ",\n"; in ReportContext()
123 out << indent << FormatKV("host_name", context.sys_info.name) << ",\n"; in ReportContext()
126 out << indent << FormatKV("executable", Context::executable_name) << ",\n"; in ReportContext()
130 out << indent << FormatKV("num_cpus", static_cast<int64_t>(info.num_cpus)) in ReportContext()
132 out << indent in ReportContext()
137 out << indent in ReportContext()
143 out << indent << "\"caches\": [\n"; in ReportContext()
[all …]
/llvm-project/clang/test/CodeGenCUDA/
H A Dbuiltins-sm90.cu4 __attribute__((global)) void kernel(long *out, void *ptr, unsigned u) { in kernel() argument
7 out[i++] = __nvvm_isspacep_shared_cluster(ptr); in kernel()
10 out[i++] = __nvvm_read_ptx_sreg_clusterid_x(); in kernel()
12 out[i++] = __nvvm_read_ptx_sreg_clusterid_y(); in kernel()
14 out[i++] = __nvvm_read_ptx_sreg_clusterid_z(); in kernel()
16 out[i++] = __nvvm_read_ptx_sreg_clusterid_w(); in kernel()
18 out[i++] = __nvvm_read_ptx_sreg_nclusterid_x(); in kernel()
20 out[i++] = __nvvm_read_ptx_sreg_nclusterid_y(); in kernel()
22 out[i++] = __nvvm_read_ptx_sreg_nclusterid_z(); in kernel()
24 out[i++] = __nvvm_read_ptx_sreg_nclusterid_w(); in kernel()
[all …]
/llvm-project/libcxx/test/std/algorithms/alg.sorting/alg.merge/
H A Dranges_merge.pass.cpp112 std::array<int, N1 + N2> out; in testMergeImpl() local
118 Out{out.data()}); in testMergeImpl()
119 assert(std::ranges::equal(out, expected)); in testMergeImpl()
123 assert(base(result.out) == out.data() + out.size()); in testMergeImpl()
128 std::array<int, N1 + N2> out; in testMergeImpl() local
131 …s<merge_result<In1, In2, Out>> decltype(auto) result = std::ranges::merge(r1, r2, Out{out.data()}); in testMergeImpl()
132 assert(std::ranges::equal(out, expected)); in testMergeImpl()
136 assert(base(result.out) == out.data() + out.size()); in testMergeImpl()
210 std::array<int, 7> out; in testImpl() local
212 std::ranges::merge(r1, NonBorrowedRange<In2>{r2.data(), r2.size()}, out.data()); in testImpl()
[all …]
/llvm-project/libcxx/test/std/re/re.results/re.results.form/
H A Dform1.pass.cpp31 char out[100] = {0}; in main() local
33 auto r = m.format(cpp17_output_iterator<char*>(out), in main()
35 assert(base(r) == out + 58); in main()
36 assert(std::string(out) == "prefix: ab, match: cdefghi, suffix: jk, m[1]: efg, m[2]: e"); in main()
44 char out[100] = {0}; in main() local
46 auto r = m.format(cpp17_output_iterator<char*>(out), in main()
48 assert(base(r) == out + 54); in main()
49 assert(std::string(out) == "prefix: ab, match: cdefghi, suffix: jk, m[1]: , m[2]: "); in main()
56 char out[100] = {0}; in main() local
58 auto r = m.format(cpp17_output_iterator<char*>(out), in main()
[all …]
/llvm-project/libcxx/test/std/algorithms/alg.modifying.operations/alg.move/
H A Dranges.move_backward.pass.cpp36 …t HasMoveBackwardIt = requires(In in, Sent sent, Out out) { std::ranges::move_backward(in, sent, o…
49 concept HasMoveBackwardR = requires(Range range, Out out) { std::ranges::move_backward(range, out);…
66 std::array<int, N> out; in test() local
68 …anges::move_backward(In(in.data()), Sent(In(in.data() + in.size())), Out(out.data() + out.size())); in test()
69 assert(in == out); in test()
71 assert(base(ret.out) == out.data()); in test()
74 std::array<int, N> out; in test() local
77 std::ranges::move_backward(range, Out(out.data() + out.size())); in test()
78 assert(in == out); in test()
80 assert(base(ret.out) == out.data()); in test()
[all …]
/llvm-project/libcxx/test/std/algorithms/alg.sorting/alg.set.operations/set.intersection/
H A Dranges_set_intersection.pass.cpp109 std::array<int, N3> out; in testSetIntersectionImpl()
115 Out{out.data()}); in testSetIntersectionImpl()
116 assert(std::ranges::equal(out, expected)); in testSetIntersectionImpl()
120 assert(base(result.out) == out.data() + out.size()); in testSetIntersectionImpl()
125 std::array<int, N3> out; in testSetIntersectionImpl()
129 std::ranges::set_intersection(r1, r2, Out{out.data()}); in testSetIntersectionImpl()
130 assert(std::ranges::equal(out, expected)); in testSetIntersectionImpl()
134 assert(base(result.out) in testSetIntersectionImpl()
107 std::array<int, N3> out; testSetIntersectionImpl() local
123 std::array<int, N3> out; testSetIntersectionImpl() local
230 std::array<int, 2> out; testImpl() local
283 std::array<TracedCopy, 2> out; test() local
296 std::array<TracedCopy, 2> out; test() local
325 std::array<IntAndOrder, 3> out; test() local
334 std::array<IntAndOrder, 3> out; test() local
355 std::array<Data, 1> out; test() local
370 std::array<Data, 1> out; test() local
384 std::array<Data, 1> out; test() local
397 std::array<Data, 1> out; test() local
417 std::array<Data, 2> out; test() local
430 std::array<Data, 2> out; test() local
442 std::array<Data, 2> out; test() local
455 std::array<Data, 2> out; test() local
476 std::array<Data, 0> out{}; test() local
506 std::array<Data, 0> out{}; test() local
548 std::array<Data, 2> out; test() local
555 std::array<Data, 2> out; test() local
[all...]
/llvm-project/libcxx/test/std/algorithms/alg.sorting/alg.set.operations/set.difference/
H A Dranges_set_difference.pass.cpp113 std::array<int, N3> out; in testSetDifferenceImpl() local
119 Out{out.data()}); in testSetDifferenceImpl()
120 assert(std::ranges::equal(out, expected)); in testSetDifferenceImpl()
123 assert(base(result.out) == out.data() + out.size()); in testSetDifferenceImpl()
128 std::array<int, N3> out; in testSetDifferenceImpl() local
132 std::ranges::set_difference(r1, r2, Out{out.data()}); in testSetDifferenceImpl()
133 assert(std::ranges::equal(out, expected)); in testSetDifferenceImpl()
136 assert(base(result.out) == out.data() + out.size()); in testSetDifferenceImpl()
218 std::array<int, 2> out; in testImpl() local
220 std::ranges::set_difference(NonBorrowedRange<In1>{r1.data(), r1.size()}, r2, out.data()); in testImpl()
[all …]

12345678910>>...182